const svg = d3.select('svg');
//projection used
const projection = d3.geoMercator();
let currentSimplyThd = 0; 
//reading json file
d3.json('https://gist.githubusercontent.com/Sheela2930/abf14c22751fcd215eead0894447b247/raw/3927870c9b37789f01dcf984789acd490e2209f9/japan.json', function(json) {
	//Add data for simplicity (the area of a triangle connecting three adjacent points)
	const presimplify = topojson.presimplify(json);
	//topjson->geojson
	const geojson = topojson.feature(presimplify, presimplify.objects.japan);
	//Execution of drawing process
	draw(geojson, currentSimplyThd);
	
	const reDraw = draw.bind(null, geojson);
	
	
	d3.select("#range").on("input", function(){
		currentSimplyThd = this.value;
		reDraw(currentSimplyThd);
	});
	
	d3.select(window).on("resize", function(){
		reDraw(currentSimplyThd);
	});
	
});


//Drawing  terrain
function draw(geojson, threshold){
	const w = svg.node().clientWidth;
	const h = svg.node().clientHeight;
	
	projection.fitExtent([[0, 0], [w, h]], geojson);
	
	//custom stream listeners for simplicity
	const simplify= d3.geoTransform({
		point: function(x, y, z) {
			//Convert  areas that are connected by 3 points above the threshold to pixel coordinates
			if (z >= threshold)  this.stream.point(projection([x, y]));
		} 
	});
	
	//Generating a fnc to convert a collection of pixcel coordinates to a path data format passed to the attribute of the path element		
	const path = d3.geoPath().projection(simplify);　
	
	 const tooltip = d3.select('body').append('div')
        .attr('class', 'tooltip')
        .style('opacity', 0);
    
    function handleMouseOver(d, i) {
        // Change fill color of region on hover
        d3.select(this)
            .attr('fill', 'LightGreen');
        
        // Show tooltip with region name on hover
        tooltip.transition()
            .duration(200)
            .style('opacity', 0.9);
        tooltip.html(d.properties.name)
            .style('left', (d3.event.pageX + 10) + 'px')
            .style('top', (d3.event.pageY - 20) + 'px');
    }
    
    function handleMouseOut(d, i) {
        // Change fill color back to original on mouseout
        d3.select(this)
            .attr('fill', 'HoneyDew');
        
        // Hide tooltip on mouseout
        tooltip.transition()
            .duration(500)
            .style('opacity', 0);
    }
    
    // Add path elements for each region
    const updateMaps = svg.selectAll('.map')
        .data(geojson.features);
    
    updateMaps.enter()
        .append("path")
        .attr("class", "map")
        .attr("fill", "teal")
        .attr("stroke", "black")
        .on('mouseover', handleMouseOver)
        .on('mouseout', handleMouseOut)
        .merge(updateMaps)
        .attr("d", path);